@@ -1,4 +1,5 @@
 // BZip2InputStream.cs
+//
 // Copyright (C) 2001 Mike Krueger
 //
 // This program is free software; you can redistribute it and/or
@@ -41,67 +42,60 @@ namespace ICSharpCode.SharpZipLib.BZip2
 {
 	
 	/// <summary>
-	/// An input stream that decompresses from the BZip2 format (without the file
-	/// header chars) to be read as any other stream.
+	/// An input stream that decompresses files in the BZip2 format 
 	/// </summary>
 	public class BZip2InputStream : Stream
 	{
 		/// <summary>
-		/// I needed to implement the abstract member.
+		/// Gets a value indicating if the stream supports reading
 		/// </summary>
-		public override bool CanRead 
-		{
-			get 
-			{
+		public override bool CanRead {
+			get {
 				return baseStream.CanRead;
 			}
 		}
 		
 		/// <summary>
-		/// I needed to implement the abstract member.
+		/// Gets a value indicating whether the current stream supports seeking.
 		/// </summary>
-		public override bool CanSeek 
-		{
-			get 
-			{
+		public override bool CanSeek {
+			get {
 				return baseStream.CanSeek;
 			}
 		}
 		
 		/// <summary>
-		/// I needed to implement the abstract member.
+		/// Gets a value indicating whether the current stream supports writing.
+		/// This property always returns false
 		/// </summary>
-		public override bool CanWrite 
-		{
-			get 
-			{
-				return baseStream.CanWrite;
+		public override bool CanWrite {
+			get {
+//				return baseStream.CanWrite;
+				return false;
 			}
 		}
 		
 		/// <summary>
-		/// I needed to implement the abstract member.
+		/// Gets the length in bytes of the stream.
 		/// </summary>
-		public override long Length 
-		{
-			get 
-			{
+		public override long Length {
+			get {
 				return baseStream.Length;
 			}
 		}
 		
 		/// <summary>
-		/// I needed to implement the abstract member.
+		/// Gets or sets the streams position
+		/// Setting the position is not supported and will throw a NotSupportException
 		/// </summary>
-		public override long Position 
-		{
-			get 
-			{
+		/// <exception cref="NotSupportedException">Any attempt to set the position</exception>
+		public override long Position {
+			get {
 				return baseStream.Position;
 			}
-			set 
-			{
-				baseStream.Position = value;
+			set {
+//				baseStream.Position = value;
+				throw new NotSupportedException("BZip2InputStream position cannot be set");
 			}
 		}
 		
@@ -110,51 +104,65 @@ namespace ICSharpCode.SharpZipLib.BZip2
 		/// </summary>
 		public override void Flush()
 		{
-			if (baseStream != null) 
-			{
+			if (baseStream != null) {
 				baseStream.Flush();
 			}
 		}
 		
 		/// <summary>
-		/// I needed to implement the abstract member.
+		/// Set the streams position.  This operation is not supported and will throw a NotSupportedException
 		/// </summary>
+		/// <exception cref="NotSupportedException">Any access</exception>
 		public override long Seek(long offset, SeekOrigin origin)
 		{
-			return baseStream.Seek(offset, origin);
+			throw new NotSupportedException("BZip2InputStream Seek not supported");
 		}
 		
 		/// <summary>
-		/// I needed to implement the abstract member.
+		/// Sets the length of this stream to the given value.
+		/// This operation is not supported and will throw a NotSupportedExceptionortedException
 		/// </summary>
+		/// <exception cref="NotSupportedException">Any access</exception>
 		public override void SetLength(long val)
 		{
-			baseStream.SetLength(val);
+			throw new NotSupportedException("BZip2InputStream SetLength not supported");
 		}
 		
 		/// <summary>
-		/// I needed to implement the abstract member.
+		/// Writes a block of bytes to this stream using data from a buffer.
+		/// This operation is not supported and will throw a NotSupportedException
 		/// </summary>
+		/// <exception cref="NotSupportedException">Any access</exception>
 		public override void Write(byte[] array, int offset, int count)
 		{
-			baseStream.Write(array, offset, count);
+			throw new NotSupportedException("BZip2InputStream Write not supported");
 		}
 		
 		/// <summary>
-		/// I needed to implement the abstract member.
+		/// Writes a byte to the current position in the file stream.
+		/// This operation is not supported and will throw a NotSupportedException
 		/// </summary>
+		/// <exception cref="NotSupportedException">Any access</exception>
 		public override void WriteByte(byte val)
 		{
-			baseStream.WriteByte(val);
+			throw new NotSupportedException("BZip2InputStream WriteByte not supported");
 		}
 		
+		/// <summary>
+		/// Read a sequence of bytes and advance position in stream
+		/// </summary>
+		/// <param name="b">Array of bytes to store values in</param>
+		/// <param name="off">Offset in array to begin storing data</param>
+		/// <param name="len">The maximum number of bytes to read</param>
+		/// <returns>The total number of bytes read into the buffer. This might be less
+		/// than the number of bytes requested if that number of bytes are not 
+		/// currently available or zero if the end of the stream is reached.
+		/// </returns>
 		public override int Read(byte[] b, int off, int len)
 		{
-			for (int i = 0; i < len; ++i) 
-			{
+			for (int i = 0; i < len; ++i) {
 				int rb = ReadByte();
-				if (rb == -1) 
-				{
+				if (rb == -1) {
 					return i;
 				}
 				b[off + i] = (byte)rb;
@@ -167,40 +175,16 @@ namespace ICSharpCode.SharpZipLib.BZip2
 		/// </summary>
 		public override void Close()
 		{
-			if (baseStream != null) 
-			{
+			if (baseStream != null) {
 				baseStream.Close();
 			}
 		}
 		
-		static void Cadvise()
-		{
-			//Console.WriteLine("CRC Error");
-			//throw new CCoruptionError();
-		}
-		
-		static void BadBGLengths() 
-		{
-			//Console.WriteLine("bad BG lengths");
-		}
-		
-		static void bitStreamEOF() 
-		{
-			//Console.WriteLine("bit stream eof");
-		}
-		
-		static void CompressedStreamEOF() 
-		{
-			//Console.WriteLine("compressed stream eof");
-		}
-		
 		void MakeMaps() 
 		{
 			nInUse = 0;
-			for (int i = 0; i < 256; ++i) 
-			{
-				if (inUse[i]) 
-				{
+			for (int i = 0; i < 256; ++i) {
+				if (inUse[i]) {
 					seqToUnseq[nInUse] = (byte)i;
 					unseqToSeq[i] = (byte)nInUse;
 					nInUse++;
@@ -227,8 +211,6 @@ namespace ICSharpCode.SharpZipLib.BZip2
 		
 		bool blockRandomised;
 		
-		//		private int bytesIn;
-		//		private int bytesOut;
 		int bsBuff;
 		int bsLive;
 		IChecksum mCrc = new StrangeCRC();
@@ -282,11 +264,14 @@ namespace ICSharpCode.SharpZipLib.BZip2
 		int i2, j2;
 		byte z;
 		
-		public BZip2InputStream(Stream zStream) 
+		/// <summary>
+		/// Construct instance for reading from stream
+		/// </summary>
+		/// <param name="stream">Data source</param>
+		public BZip2InputStream(Stream stream) 
 		{
 			// init arrays
-			for (int i = 0; i < BZip2Constants.N_GROUPS; ++i) 
-			{
+			for (int i = 0; i < BZip2Constants.N_GROUPS; ++i) {
 				limit[i] = new int[BZip2Constants.MAX_ALPHA_SIZE];
 				baseArray[i]  = new int[BZip2Constants.MAX_ALPHA_SIZE];
 				perm[i]  = new int[BZip2Constants.MAX_ALPHA_SIZE];
@@ -294,22 +279,24 @@ namespace ICSharpCode.SharpZipLib.BZip2
 			
 			ll8 = null;
 			tt  = null;
-			BsSetStream(zStream);
+			BsSetStream(stream);
 			Initialize();
 			InitBlock();
 			SetupBlock();
 		}
 		
+		/// <summary>
+		/// Read a byte from stream advancing position
+		/// </summary>
+		/// <returns>byte read or -1 on end of stream</returns>
 		public override int ReadByte()
 		{
-			if (streamEnd) 
-			{
-				return -1;
+			if (streamEnd) {
+				return -1; // ok
 			}
 			
 			int retChar = currentChar;
-			switch (currentState) 
-			{
+			switch (currentState) {
 				case RAND_PART_B_STATE:
 					SetupRandPartB();
 					break;
@@ -334,11 +321,13 @@ namespace ICSharpCode.SharpZipLib.BZip2
 		
 		void Initialize() 
 		{
+			char magic1 = BsGetUChar();
+			char magic2 = BsGetUChar();
+			
 			char magic3 = BsGetUChar();
 			char magic4 = BsGetUChar();
 			
-			if (magic3 != 'h' || magic4 < '1' || magic4 > '9') 
-			{
+			if (magic1 != 'B' || magic2 != 'Z' || magic3 != 'h' || magic4 < '1' || magic4 > '9') {
 				streamEnd = true;
 				return;
 			}
@@ -356,14 +345,12 @@ namespace ICSharpCode.SharpZipLib.BZip2
 			char magic5 = BsGetUChar();
 			char magic6 = BsGetUChar();
 			
-			if (magic1 == 0x17 && magic2 == 0x72 && magic3 == 0x45 && magic4 == 0x38 && magic5 == 0x50 && magic6 == 0x90) 
-			{
+			if (magic1 == 0x17 && magic2 == 0x72 && magic3 == 0x45 && magic4 == 0x38 && magic5 == 0x50 && magic6 == 0x90) {
 				Complete();
 				return;
 			}
 			
-			if (magic1 != 0x31 || magic2 != 0x41 || magic3 != 0x59 || magic4 != 0x26 || magic5 != 0x53 || magic6 != 0x59) 
-			{
+			if (magic1 != 0x31 || magic2 != 0x41 || magic3 != 0x59 || magic4 != 0x26 || magic5 != 0x53 || magic6 != 0x59) {
 				BadBlockHeader();
 				streamEnd = true;
 				return;
@@ -373,7 +360,6 @@ namespace ICSharpCode.SharpZipLib.BZip2
 			
 			blockRandomised = (BsR(1) == 1);
 			
-			//		currBlockNo++;
 			GetAndMoveToFrontDecode();
 			
 			mCrc.Reset();
@@ -385,8 +371,7 @@ namespace ICSharpCode.SharpZipLib.BZip2
 			computedBlockCRC = (int)mCrc.Value;
 			
 			/*-- A bad CRC is considered a fatal error. --*/
-			if (storedBlockCRC != computedBlockCRC) 
-			{
+			if (storedBlockCRC != computedBlockCRC) {
 				CrcError();
 			}
 			
@@ -398,27 +383,31 @@ namespace ICSharpCode.SharpZipLib.BZip2
 		void Complete() 
 		{
 			storedCombinedCRC = BsGetInt32();
-			if (storedCombinedCRC != (int)computedCombinedCRC) 
-			{
+			if (storedCombinedCRC != (int)computedCombinedCRC) {
 				CrcError();
 			}
 			
 			streamEnd = true;
 		}
 		
+		static void CompressedStreamEOF() 
+		{
+			throw new ApplicationException("BZip2 input stream end of compressed stream");
+		}
+		
 		static void BlockOverrun() 
 		{
-			//Console.WriteLine("Block overrun");
+			throw new ApplicationException("BZip2 input stream block overrun");
 		}
 		
 		static void BadBlockHeader() 
 		{
-			//Console.WriteLine("Bad block header");
+			throw new ApplicationException("BZip2 input stream bad block header");
 		}
 		
 		static void CrcError() 
 		{
-			//Console.WriteLine("crc error");
+			throw new ApplicationException("BZip2 input stream crc error");
 		}
 		
 		
@@ -433,17 +422,13 @@ namespace ICSharpCode.SharpZipLib.BZip2
 		{
 			int thech = 0;
 			
-			try 
-			{
+			try {
 				thech = baseStream.ReadByte();
-			} 
-			catch (Exception) 
-			{
+			} catch (Exception) {
 				CompressedStreamEOF();
 			}
 			
-			if (thech == -1) 
-			{
+			if (thech == -1) {
 				CompressedStreamEOF();
 			}
 			
@@ -453,8 +438,7 @@ namespace ICSharpCode.SharpZipLib.BZip2
 		
 		int BsR(int n) 
 		{
-			while (bsLive < n) 
-			{
+			while (bsLive < n) {
 				FillBuffer();
 			}
 			
@@ -492,49 +476,40 @@ namespace ICSharpCode.SharpZipLib.BZip2
 		{
 			int pp = 0;
 			
-			for (int i = minLen; i <= maxLen; ++i) 
-			{
-				for (int j = 0; j < alphaSize; ++j) 
-				{
-					if (length[j] == i) 
-					{
+			for (int i = minLen; i <= maxLen; ++i) {
+				for (int j = 0; j < alphaSize; ++j) {
+					if (length[j] == i) {
 						perm[pp] = j;
 						++pp;
 					}
 				}
 			}
 			
-			for (int i = 0; i < BZip2Constants.MAX_CODE_LEN; i++) 
-			{
+			for (int i = 0; i < BZip2Constants.MAX_CODE_LEN; i++) {
 				baseArray[i] = 0;
 			}
 			
-			for (int i = 0; i < alphaSize; i++) 
-			{
+			for (int i = 0; i < alphaSize; i++) {
 				++baseArray[length[i] + 1];
 			}
 			
-			for (int i = 1; i < BZip2Constants.MAX_CODE_LEN; i++) 
-			{
+			for (int i = 1; i < BZip2Constants.MAX_CODE_LEN; i++) {
 				baseArray[i] += baseArray[i - 1];
 			}
 			
-			for (int i = 0; i < BZip2Constants.MAX_CODE_LEN; i++) 
-			{
+			for (int i = 0; i < BZip2Constants.MAX_CODE_LEN; i++) {
 				limit[i] = 0;
 			}
 			
 			int vec = 0;
 			
-			for (int i = minLen; i <= maxLen; i++) 
-			{
+			for (int i = minLen; i <= maxLen; i++) {
 				vec += (baseArray[i + 1] - baseArray[i]);
 				limit[i] = vec - 1;
 				vec <<= 1;
 			}
 			
-			for (int i = minLen + 1; i <= maxLen; i++) 
-			{
+			for (int i = minLen + 1; i <= maxLen; i++) {
 				baseArray[i] = ((limit[i - 1] + 1) << 1) - baseArray[i];
 			}
 		}
@@ -542,27 +517,26 @@ namespace ICSharpCode.SharpZipLib.BZip2
 		void RecvDecodingTables() 
 		{
 			char[][] len = new char[BZip2Constants.N_GROUPS][];
-			for (int i = 0; i < BZip2Constants.N_GROUPS; ++i) 
-			{
+			for (int i = 0; i < BZip2Constants.N_GROUPS; ++i) {
 				len[i] = new char[BZip2Constants.MAX_ALPHA_SIZE];
 			}
 			
 			bool[] inUse16 = new bool[16];
 			
 			/*--- Receive the mapping table ---*/
-			for (int i = 0; i < 16; i++) 
-			{
+			for (int i = 0; i < 16; i++) {
 				inUse16[i] = (BsR(1) == 1);
 			} 
 			
-			for (int i = 0; i < 16; i++) 
-			{
-				if (inUse16[i]) 
-				{
-					for (int j = 0; j < 16; j++) 
-					{
+			for (int i = 0; i < 16; i++) {
+				if (inUse16[i]) {
+					for (int j = 0; j < 16; j++) {
 						inUse[i * 16 + j] = (BsR(1) == 1);
 					}
+				} else {
+					for (int j = 0; j < 16; j++) {
+						inUse[i * 16 + j] = false;
+					}
 				}
 			}
 			
@@ -573,11 +547,9 @@ namespace ICSharpCode.SharpZipLib.BZip2
 			int nGroups    = BsR(3);
 			int nSelectors = BsR(15);
 			
-			for (int i = 0; i < nSelectors; i++) 
-			{
+			for (int i = 0; i < nSelectors; i++) {
 				int j = 0;
-				while (BsR(1) == 1) 
-				{
+				while (BsR(1) == 1) {
 					j++;
 				}
 				selectorMtf[i] = (byte)j;
@@ -585,17 +557,14 @@ namespace ICSharpCode.SharpZipLib.BZip2
 			
 			/*--- Undo the MTF values for the selectors. ---*/
 			byte[] pos = new byte[BZip2Constants.N_GROUPS];
-			for (int v = 0; v < nGroups; v++) 
-			{
+			for (int v = 0; v < nGroups; v++) {
 				pos[v] = (byte)v;
 			}
 			
-			for (int i = 0; i < nSelectors; i++) 
-			{
+			for (int i = 0; i < nSelectors; i++) {
 				int  v   = selectorMtf[i];
 				byte tmp = pos[v];
-				while (v > 0) 
-				{
+				while (v > 0) {
 					pos[v] = pos[v - 1];
 					v--;
 				}
@@ -604,19 +573,13 @@ namespace ICSharpCode.SharpZipLib.BZip2
 			}
 			
 			/*--- Now the coding tables ---*/
-			for (int t = 0; t < nGroups; t++) 
-			{
+			for (int t = 0; t < nGroups; t++) {
 				int curr = BsR(5);
-				for (int i = 0; i < alphaSize; i++) 
-				{
-					while (BsR(1) == 1) 
-					{
-						if (BsR(1) == 0) 
-						{
+				for (int i = 0; i < alphaSize; i++) {
+					while (BsR(1) == 1) {
+						if (BsR(1) == 0) {
 							curr++;
-						} 
-						else 
-						{
+						} else {
 							curr--;
 						}
 					}
@@ -625,12 +588,10 @@ namespace ICSharpCode.SharpZipLib.BZip2
 			}
 			
 			/*--- Create the Huffman decoding tables ---*/
-			for (int t = 0; t < nGroups; t++) 
-			{
+			for (int t = 0; t < nGroups; t++) {
 				int minLen = 32;
 				int maxLen = 0;
-				for (int i = 0; i < alphaSize; i++) 
-				{
+				for (int i = 0; i < alphaSize; i++) {
 					maxLen = Math.Max(maxLen, len[t][i]);
 					minLen = Math.Min(minLen, len[t][i]);
 				}
@@ -658,20 +619,17 @@ namespace ICSharpCode.SharpZipLib.BZip2
 			in a separate pass, and so saves a block's worth of
 			cache misses.
 			--*/
-			for (int i = 0; i <= 255; i++) 
-			{
+			for (int i = 0; i <= 255; i++) {
 				unzftab[i] = 0;
 			}
 			
-			for (int i = 0; i <= 255; i++) 
-			{
+			for (int i = 0; i <= 255; i++) {
 				yy[i] = (byte)i;
 			}
 			
 			last = -1;
 			
-			if (groupPos == 0) 
-			{
+			if (groupPos == 0) {
 				groupNo++;
 				groupPos = BZip2Constants.G_SIZE;
 			}
@@ -682,46 +640,41 @@ namespace ICSharpCode.SharpZipLib.BZip2
 			int zvec = BsR(zn);
 			int zj;
 			
-			while (zvec > limit[zt][zn]) 
-			{
+			while (zvec > limit[zt][zn]) {
+				if (zn > 20) { // the longest code
+					throw new ApplicationException("Bzip data error");  // -jr- 17-Dec-2003 from bzip 1.02 why 20???
+				}
 				zn++;
-				while (bsLive < 1) 
-				{
+				while (bsLive < 1) {
 					FillBuffer();
 				}
 				zj = (bsBuff >> (bsLive-1)) & 1;
 				bsLive--;
 				zvec = (zvec << 1) | zj;
 			}
+			if (zvec - baseArray[zt][zn] < 0 || zvec - baseArray[zt][zn] >= BZip2Constants.MAX_ALPHA_SIZE) {
+				throw new ApplicationException("Bzip data error");  // -jr- 17-Dec-2003 from bzip 1.02
+			}
 			nextSym = perm[zt][zvec - baseArray[zt][zn]];
 			
-			while (true) 
-			{
-				
-				if (nextSym == EOB) 
-				{
+			while (true) {
+				if (nextSym == EOB) {
 					break;
 				}
 				
-				if (nextSym == BZip2Constants.RUNA || nextSym == BZip2Constants.RUNB) 
-				{
+				if (nextSym == BZip2Constants.RUNA || nextSym == BZip2Constants.RUNB) {
 					int s = -1;
 					int n = 1;
-					do 
-					{
-						if (nextSym == BZip2Constants.RUNA) 
-						{
-							s += (0+1) * n;
-						} 
-						else if (nextSym == BZip2Constants.RUNB) 
-						{
-							s += (1+1) * n;
+					do {
+						if (nextSym == BZip2Constants.RUNA) {
+							s += (0 + 1) * n;
+						} else if (nextSym == BZip2Constants.RUNB) {
+							s += (1 + 1) * n;
 						}
 
 						n <<= 1;
 						
-						if (groupPos == 0) 
-						{
+						if (groupPos == 0) {
 							groupNo++;
 							groupPos = BZip2Constants.G_SIZE;
 						}
@@ -732,17 +685,15 @@ namespace ICSharpCode.SharpZipLib.BZip2
 						zn = minLens[zt];
 						zvec = BsR(zn);
 						
-					while (zvec > limit[zt][zn]) 
-					{
-						zn++;
-						while (bsLive < 1) 
-						{
-							FillBuffer();
+						while (zvec > limit[zt][zn]) {
+							zn++;
+							while (bsLive < 1) {
+								FillBuffer();
+							}
+							zj = (bsBuff >> (bsLive - 1)) & 1;
+							bsLive--;
+							zvec = (zvec << 1) | zj;
 						}
-						zj = (bsBuff >> (bsLive - 1)) & 1;
-						bsLive--;
-						zvec = (zvec << 1) | zj;
-					}
 						nextSym = perm[zt][zvec - baseArray[zt][zn]];
 					} while (nextSym == BZip2Constants.RUNA || nextSym == BZip2Constants.RUNB);
 					
@@ -750,24 +701,19 @@ namespace ICSharpCode.SharpZipLib.BZip2
 					byte ch = seqToUnseq[yy[0]];
 					unzftab[ch] += s;
 					
-					while (s > 0) 
-					{
+					while (s > 0) {
 						last++;
 						ll8[last] = ch;
 						s--;
 					}
 					
-					if (last >= limitLast) 
-					{
+					if (last >= limitLast) {
 						BlockOverrun();
 					}
 					continue;
-				} 
-				else 
-				{
+				} else {
 					last++;
-					if (last >= limitLast) 
-					{
+					if (last >= limitLast) {
 						BlockOverrun();
 					}
 					
@@ -775,14 +721,12 @@ namespace ICSharpCode.SharpZipLib.BZip2
 					unzftab[seqToUnseq[tmp]]++;
 					ll8[last] = seqToUnseq[tmp];
 					
-					for (int j = nextSym-1; j > 0; --j) 
-					{
+					for (int j = nextSym-1; j > 0; --j) {
 						yy[j] = yy[j - 1];
 					}
 					yy[0] = tmp;
 					
-					if (groupPos == 0) 
-					{
+					if (groupPos == 0) {
 						groupNo++;
 						groupPos = BZip2Constants.G_SIZE;
 					}
@@ -791,11 +735,9 @@ namespace ICSharpCode.SharpZipLib.BZip2
 					zt = selector[groupNo];
 					zn = minLens[zt];
 					zvec = BsR(zn);
-					while (zvec > limit[zt][zn]) 
-					{
+					while (zvec > limit[zt][zn]) {
 						zn++;
-						while (bsLive < 1) 
-						{
+						while (bsLive < 1) {
 							FillBuffer();
 						}
 						zj = (bsBuff >> (bsLive-1)) & 1;
@@ -815,13 +757,11 @@ namespace ICSharpCode.SharpZipLib.BZip2
 			cftab[0] = 0;
 			Array.Copy(unzftab, 0, cftab, 1, 256);
 			
-			for (int i = 1; i <= 256; i++) 
-			{
+			for (int i = 1; i <= 256; i++) {
 				cftab[i] += cftab[i - 1];
 			}
 			
-			for (int i = 0; i <= last; i++) 
-			{
+			for (int i = 0; i <= last; i++) {
 				byte ch = ll8[i];
 				tt[cftab[ch]] = i;
 				cftab[ch]++;
@@ -835,31 +775,25 @@ namespace ICSharpCode.SharpZipLib.BZip2
 			i2    = 0;
 			ch2   = 256;   /*-- not a char and not EOF --*/
 			
-			if (blockRandomised) 
-			{
+			if (blockRandomised) {
 				rNToGo = 0;
 				rTPos = 0;
 				SetupRandPartA();
-			} 
-			else 
-			{
+			} else {
 				SetupNoRandPartA();
 			}
 		}
 		
 		void SetupRandPartA() 
 		{
-			if(i2 <= last) 
-			{
+			if (i2 <= last) {
 				chPrev = ch2;
 				ch2  = ll8[tPos];
 				tPos = tt[tPos];
-				if (rNToGo == 0) 
-				{
+				if (rNToGo == 0) {
 					rNToGo = BZip2Constants.rNums[rTPos];
 					rTPos++;
-					if(rTPos == 512) 
-					{
+					if (rTPos == 512) {
 						rTPos = 0;
 					}
 				}
@@ -870,9 +804,7 @@ namespace ICSharpCode.SharpZipLib.BZip2
 				currentChar  = ch2;
 				currentState = RAND_PART_B_STATE;
 				mCrc.Update(ch2);
-			} 
-			else 
-			{
+			} else {
 				EndBlock();
 				InitBlock();
 				SetupBlock();
@@ -881,8 +813,7 @@ namespace ICSharpCode.SharpZipLib.BZip2
 		
 		void SetupNoRandPartA() 
 		{
-			if (i2 <= last) 
-			{
+			if (i2 <= last) {
 				chPrev = ch2;
 				ch2  = ll8[tPos];
 				tPos = tt[tPos];
@@ -891,9 +822,7 @@ namespace ICSharpCode.SharpZipLib.BZip2
 				currentChar = ch2;
 				currentState = NO_RAND_PART_B_STATE;
 				mCrc.Update(ch2);
-			} 
-			else 
-			{
+			} else {
 				EndBlock();
 				InitBlock();
 				SetupBlock();
@@ -902,25 +831,19 @@ namespace ICSharpCode.SharpZipLib.BZip2
 		
 		void SetupRandPartB() 
 		{
-			if (ch2 != chPrev) 
-			{
+			if (ch2 != chPrev) {
 				currentState = RAND_PART_A_STATE;
 				count = 1;
 				SetupRandPartA();
-			} 
-			else 
-			{
+			} else {
 				count++;
-				if (count >= 4) 
-				{
+				if (count >= 4) {
 					z = ll8[tPos];
 					tPos = tt[tPos];
-					if (rNToGo == 0) 
-					{
+					if (rNToGo == 0) {
 						rNToGo = BZip2Constants.rNums[rTPos];
 						rTPos++;
-						if (rTPos == 512) 
-						{
+						if (rTPos == 512) {
 							rTPos = 0;
 						}
 					}
@@ -929,9 +852,7 @@ namespace ICSharpCode.SharpZipLib.BZip2
 					j2 = 0;
 					currentState = RAND_PART_C_STATE;
 					SetupRandPartC();
-				} 
-				else 
-				{
+				} else {
 					currentState = RAND_PART_A_STATE;
 					SetupRandPartA();
 				}
@@ -940,14 +861,11 @@ namespace ICSharpCode.SharpZipLib.BZip2
 		
 		void SetupRandPartC() 
 		{
-			if (j2 < (int)z) 
-			{
+			if (j2 < (int)z) {
 				currentChar = ch2;
 				mCrc.Update(ch2);
 				j2++;
-			} 
-			else 
-			{
+			} else {
 				currentState = RAND_PART_A_STATE;
 				i2++;
 				count = 0;
@@ -957,25 +875,19 @@ namespace ICSharpCode.SharpZipLib.BZip2
 		
 		void SetupNoRandPartB() 
 		{
-			if (ch2 != chPrev) 
-			{
+			if (ch2 != chPrev) {
 				currentState = NO_RAND_PART_A_STATE;
 				count = 1;
 				SetupNoRandPartA();
-			} 
-			else 
-			{
+			} else {
 				count++;
-				if (count >= 4) 
-				{
+				if (count >= 4) {
 					z = ll8[tPos];
 					tPos = tt[tPos];
 					currentState = NO_RAND_PART_C_STATE;
 					j2 = 0;
 					SetupNoRandPartC();
-				} 
-				else 
-				{
+				} else {
 					currentState = NO_RAND_PART_A_STATE;
 					SetupNoRandPartA();
 				}
@@ -984,14 +896,11 @@ namespace ICSharpCode.SharpZipLib.BZip2
 		
 		void SetupNoRandPartC() 
 		{
-			if (j2 < (int)z) 
-			{
+			if (j2 < (int)z) {
 				currentChar = ch2;
 				mCrc.Update(ch2);
 				j2++;
-			} 
-			else 
-			{
+			} else {
 				currentState = NO_RAND_PART_A_STATE;
 				i2++;
 				count = 0;
@@ -1001,16 +910,13 @@ namespace ICSharpCode.SharpZipLib.BZip2
 		
 		void SetDecompressStructureSizes(int newSize100k) 
 		{
-			if (!(0 <= newSize100k   && newSize100k <= 9 && 
-				0 <= blockSize100k && blockSize100k <= 9)) 
-			{
+			if (!(0 <= newSize100k   && newSize100k <= 9 && 0 <= blockSize100k && blockSize100k <= 9)) {
 				throw new ApplicationException("Invalid block size");
 			}
-			       
+			
 			blockSize100k = newSize100k;
 			
-			if (newSize100k == 0) 
-			{
+			if (newSize100k == 0) {
 				return;
 			}
 			
