@@ -46,6 +46,7 @@ internal sealed class DrawingWindow : InputOutputWidget, IToolkitWindow
 				this.sink = sink;
 				this.toolkit = toolkit;
 				this.AutoMapChildren = false;
+				this.DrawBackground = false;
 			}
 
 
@@ -756,6 +757,12 @@ internal sealed class DrawingWindow : InputOutputWidget, IToolkitWindow
 			{
 				base.SendBeginInvoke(i_gch);
 			}
+			
+	protected override void OnBeginInvokeMessage(IntPtr i_gch)
+			{
+				if( sink != null )
+					sink.ToolkitBeginInvoke(i_gch);
+			}
 
 }; // class DrawingWindow
 
