@@ -77,6 +77,7 @@ namespace System.Windows.Forms
 {
 
 using System.Drawing;
+using System.ComponentModel;
 
 public class ContainerControl : ScrollableControl, IContainerControl
 {
@@ -90,8 +91,12 @@ public class ContainerControl : ScrollableControl, IContainerControl
 	public ContainerControl()
 	{
 		SetStyle(ControlStyles.AllPaintingInWmPaint, false);
+		SetStyle(ControlStyles.ContainerControl, true);
 	}
 
+#if CONFIG_COMPONENT_MODEL || CONFIG_EXTENDED_DIAGNOSTICS
+	[Browsable(false)]
+#endif // CONFIG_COMPONENT_MODEL || CONFIG_EXTENDED_DIAGNOSTICS
 	public override BindingContext BindingContext
 	{
 		get
@@ -119,6 +124,10 @@ public class ContainerControl : ScrollableControl, IContainerControl
 		}
 	}
 
+#if CONFIG_COMPONENT_MODEL || CONFIG_EXTENDED_DIAGNOSTICS
+	[Browsable(false)]
+	[DesignerSerializationVisibility(DesignerSerializationVisibility.Hidden)]
+#endif // CONFIG_COMPONENT_MODEL || CONFIG_EXTENDED_DIAGNOSTICS
 	public virtual Control ActiveControl
 	{
 		get
@@ -175,6 +184,10 @@ public class ContainerControl : ScrollableControl, IContainerControl
 		}
 	}
 
+#if CONFIG_COMPONENT_MODEL || CONFIG_EXTENDED_DIAGNOSTICS
+	[Browsable(false)]
+	[DesignerSerializationVisibility(DesignerSerializationVisibility.Hidden)]
+#endif // CONFIG_COMPONENT_MODEL || CONFIG_EXTENDED_DIAGNOSTICS
 	public Form ParentForm
 	{
 		get
@@ -237,6 +250,9 @@ public class ContainerControl : ScrollableControl, IContainerControl
 		return activated;
 	}
 
+#if CONFIG_COMPONENT_MODEL
+	[EditorBrowsable(EditorBrowsableState.Advanced)]
+#endif // CONFIG_COMPONENT_MODEL
 	protected override void AdjustFormScrollbars(bool displayScrollbars)
 	{
 		AdjustFormScrollbars(displayScrollbars);
@@ -402,6 +418,9 @@ public class ContainerControl : ScrollableControl, IContainerControl
 		OnBindingContextChanged(EventArgs.Empty);
 	}
 
+#if CONFIG_COMPONENT_MODEL
+	[EditorBrowsable(EditorBrowsableState.Advanced)]
+#endif // CONFIG_COMPONENT_MODEL
 	protected override void OnControlRemoved(ControlEventArgs e)
 	{
 		Control control = e.Control;
@@ -417,6 +436,9 @@ public class ContainerControl : ScrollableControl, IContainerControl
 		base.OnControlRemoved(e);
 	}
 
+#if CONFIG_COMPONENT_MODEL
+	[EditorBrowsable(EditorBrowsableState.Advanced)]
+#endif // CONFIG_COMPONENT_MODEL
 	protected override bool ProcessDialogChar(char charCode)
 	{
 		if (GetTopLevel())
@@ -764,6 +786,9 @@ public class ContainerControl : ScrollableControl, IContainerControl
 #if !CONFIG_COMPACT_FORMS
 
 	// Process a message.
+#if CONFIG_COMPONENT_MODEL
+	[EditorBrowsable(EditorBrowsableState.Advanced)]
+#endif // CONFIG_COMPONENT_MODEL
 	protected override void WndProc(ref Message m)
 	{
 		base.WndProc(ref m);
