@@ -89,7 +89,7 @@ public sealed class ControlPaint
 					b += (temp2 - temp1) * t3 / 60.0f;
 				else if(t3 < 180.0f)
 					b = temp2;
-				else
+				else if(t3 < 240.0f)
 					b += (temp2 - temp1) * (240.0f - t3) / 60.0f;
 			}
 		}
@@ -484,15 +484,14 @@ public sealed class ControlPaint
 	public static void DrawSizeGrip
 				(Graphics graphics, Color backColor, Rectangle rectangle)
 			{
-				DrawSizeGrip(graphics, backColor, rectangle.X, rectangle.Y,
-						   	 rectangle.Width, rectangle.Height);
+				ThemeManager.MainPainter.DrawSizeGrip(graphics, backColor, rectangle);
 			}
 	public static void DrawSizeGrip
 				(Graphics graphics, Color backColor,
 				 int x, int y, int width, int height)
 			{
 				ThemeManager.MainPainter.DrawSizeGrip
-					(graphics, backColor, x, y, width, height);
+					(graphics, backColor, new Rectangle(x, y, width, height));
 			}
 
 	// Draw a disabled string.
