@@ -513,9 +513,12 @@ public class Form : ContainerControl
 				}
 				set
 				{
-					// We don't support transparent windows,
-					// so just save the value away for later.
 					opacity = value;
+					IToolkitTopLevelWindow window = (IToolkitTopLevelWindow)ToolkitWindow;
+					if(window != null)
+					{
+						window.SetOpacity(opacity);
+					}
 				}
 			}
 	public Form[] OwnedForms
@@ -594,7 +597,19 @@ public class Form : ContainerControl
 				}
 				set
 				{
-					topLevel = value;
+					// Brubbel recreate toolkitwindow, if exists
+					if( value != topLevel ) {
+						topLevel = value;
+						if( null != toolkitWindow ) {
+							Control [] copy = new Control[this.Controls.Count];
+							this.Controls.CopyTo( copy, 0 );
+							this.Controls.Clear();;
+							toolkitWindow.Destroy();
+							toolkitWindow = null;
+							this.CreateHandle();
+							this.Controls.AddRange( copy );
+						}
+					}
 				}
 			}
 	public bool TopMost
@@ -725,6 +740,10 @@ public class Form : ContainerControl
 							window.Dimensions.Height
 						);
 				}
+				if(opacity != 1.0)
+				{
+					window.SetOpacity(opacity);
+				}
 				return window;
 			}
 
@@ -736,6 +755,7 @@ public class Form : ContainerControl
 					return ((mdiParent == null) && TopLevel);
 				}
 			}
+			
 
 	// Get the current state of a window decoration flag.
 	private bool GetWindowFlag(ToolkitWindowFlags flag)
@@ -930,6 +950,7 @@ public class Form : ContainerControl
 
 					// Make the form visible.
 					Visible = true;
+					Activate();
 
 					// Enter a message loop until the dialog result is set.
 					Application.InnerMessageLoop(this);
@@ -938,7 +959,6 @@ public class Form : ContainerControl
 				{
 					// Make sure that the form is not visible.
 					Visible = false;
-
 					// The form is no longer modal.
 					SetWindowFlag(ToolkitWindowFlags.Modal, false);
 				}
