@@ -362,10 +362,11 @@ namespace System.Windows.Forms
 				tabOwner.SetTabPageBounds();
 			}
 
-			[TODO]
 			public override void Remove(Control control)
 			{
 				base.Remove(control);
+				tabOwner.InvalidateTabs	();
+				tabOwner.SetTabPageBounds();
 			}
 
 		};
@@ -381,7 +382,6 @@ namespace System.Windows.Forms
 				this.tabOwner = owner;
 			}
 
-			[TODO]
 			public TabPage this[int idx]
 			{
 				get
@@ -390,7 +390,18 @@ namespace System.Windows.Forms
 				}
 				set
 				{
-					// Handle
+					ArrayList tabpages = new ArrayList();
+					this.RemoveAt(idx);
+					for(int i = 0; i < tabOwner.Controls.Count; i++)
+					{
+						if(i != idx)
+						{
+							tabpages.Add(tabOwner.Controls[i]);
+						}
+					}
+					tabpages.Insert(idx, value);
+					tabOwner.Controls.Clear();
+					tabOwner.Controls.AddRange((TabPage[])tabpages.ToArray(typeof(TabPage)));
 				}
 			}
 
