@@ -34,6 +34,7 @@ using System.Collections;
 
 namespace System.Xml.Serialization
 {
+#if CONFIG_SERIALIZATION
 	internal class XmlSerializationReaderInterpreter: XmlSerializationReader
 	{
 		XmlMapping _typeMap;
@@ -438,6 +439,7 @@ namespace System.Xml.Serialization
 				else 
 					UnknownNode(ob);
 
+				Reader.Read();
 				Reader.MoveToContent();
 			}
 
@@ -773,4 +775,5 @@ namespace System.Xml.Serialization
 			}
 		}
 	}
+#endif // CONFIG_SERIALIZATION
 }
