@@ -23,6 +23,8 @@
 
 using System;
 
+#if CONFIG_XPATH
+
 namespace System.Xml.XPath
 {
 #if ECMA_COMPAT
@@ -32,8 +34,13 @@ public
 #endif
 abstract class XPathNodeIterator : ICloneable
 {
-	public abstract Object Clone();
+	public abstract XPathNodeIterator Clone();
 	
+	Object ICloneable.Clone()
+			{
+				return Clone();
+			}
+
 	public abstract bool MoveNext();
 
 	[TODO]
@@ -57,3 +64,5 @@ abstract class XPathNodeIterator : ICloneable
 
 }
 }//namespace
+
+#endif /* CONFIG_XPATH */
