@@ -24,6 +24,7 @@ namespace System.Xml
 
 using System;
 using System.IO;
+using System.Net;
 using System.Text;
 using System.Collections;
 using System.Xml.Private;
@@ -291,13 +292,15 @@ public class XmlTextReader : XmlReader
 			{
 				// Nothing to do here
 			}
-	[TODO]
+			
 	public XmlTextReader(String url, XmlNameTable nt)
 			: this(nt)
 			{
 				if(url == null) { throw new XmlException("url"); }
-				// TODO - handle non-file streams
-				XmlStreamReader sr = new XmlStreamReader(url, true);
+				
+				Uri uri = resolver.ResolveUri(null, url);
+				Stream stream = (Stream)resolver.GetEntity(uri, null, typeof(Stream));
+				XmlStreamReader sr = new XmlStreamReader(stream, true);
 				input.Reader = sr;
 				context.BaseURI = nt.Add(url);
 				context.Encoding = sr.CurrentEncoding;
