@@ -1582,16 +1582,7 @@ public class TopLevelWindow : InputOutputWidget
 				}
 			}
 
-	/// <summary>
-	/// <para>Method that is called when a custom "BeginInvoke" message comes in
-	/// changes.</para>
-	/// </summary>
-	protected virtual void OnBeginInvokeMessage(IntPtr i_gch)
-			{
-				// Nothing to do in this base class.
-			}
-
-
+	
 	/// <summary>
 	/// <para>Method that is called when the window's iconic state
 	/// changes.</para>
@@ -1970,10 +1961,6 @@ public class TopLevelWindow : InputOutputWidget
 								}
 							}
 						}
-						else if(xevent.xclient.message_type == dpy.internalBeginInvoke)
-						{
-							OnBeginInvokeMessage((IntPtr)xevent.xclient.l(0));
-						}
 					}
 					break;
 
@@ -2191,6 +2178,14 @@ public class TopLevelWindow : InputOutputWidget
 					}
 					break;
 
+				case Xsharp.Events.EventType.ButtonPress:
+					{
+						if ((xevent.xbutton.button == ButtonName.Button4) ||
+						    (xevent.xbutton.button == ButtonName.Button5))
+							return;
+					}
+					break;
+
 				case Xsharp.Events.EventType.ButtonRelease:
 					{
 						// Handle mouse wheel events.
@@ -2198,7 +2193,7 @@ public class TopLevelWindow : InputOutputWidget
 						// Sanity check
 						if ((xevent.xbutton.button != ButtonName.Button4) &&
 						    (xevent.xbutton.button != ButtonName.Button5))
-							return;
+							break;
 
 						// Dispatch the event.
 						widget = focusWidget;
@@ -2209,7 +2204,7 @@ public class TopLevelWindow : InputOutputWidget
 							{
 								if (io.DispatchWheelEvent (ref xevent))
 								{
-									break;
+									return;
 								}
 							}
 							if (widget == this)
@@ -2382,6 +2377,32 @@ public class TopLevelWindow : InputOutputWidget
 				}
 			}
 
+	public double Opacity
+	{
+		set
+		{
+			int op = (int)(value * 0xffffffff);
+			try
+			{	
+				IntPtr display = dpy.Lock();
+				XWindow handle = GetWidgetHandle();
+				
+				Xsharp.Xlib.XChangeProperty
+									(display, handle,
+									Xlib.XInternAtom(display, "_NET_WM_WINDOW_OPACITY",
+													XBool.False),
+									Xlib.XInternAtom(display, "CARDINAL",
+													XBool.False),
+									32, 0 /* PropModeReplace */,
+									new Xlib.Xlong [] {(Xlib.Xlong)(op)}, 1);
+			}
+			finally
+			{
+				dpy.Unlock();
+			}
+		}
+	}
+
 } // class TopLevelWindow
 
 } // namespace Xsharp
