@@ -22,6 +22,7 @@
 
 #include "XsharpSupport.h"
 
+
 int XSharpSupportPresent(void)
 {
 	return 1;
@@ -497,8 +498,6 @@ void XSharpDrawStringXft(Display *dpy, Drawable drawable, GC gc,
 	XGCValues values;
 	int line1, line2;
 
-	/* TODO: 16-bit fonts */
-
 	/* Set up the Xft color value to draw with */
 	XGetGCValues(dpy, gc, GCForeground, &values);
 	color.pixel = values.foreground;
@@ -517,8 +516,10 @@ void XSharpDrawStringXft(Display *dpy, Drawable drawable, GC gc,
 		{
 			XftDrawSetClip(draw, clipRegion);
 		}
-		XftDrawString8(draw, &color, (XftFont *)fontSet,
-					   x, y, (XftChar8 *)str, strlen(str));
+
+		XftDrawStringUtf8(draw, &color, (XftFont *)fontSet,
+			x, y, (XftChar8 *)str, strlen(str));
+		
 		XftDrawDestroy(draw);
 	}
 
@@ -643,7 +644,7 @@ void XSharpTextExtentsStruct(Display *dpy, void *fontSet, ILString *str,
 {
 	ILChar *buffer = ILStringToBuffer(str) + offset;
 	XFontStruct *fs = (XFontStruct *)fontSet;
-    int isSingleRow = (fs->max_byte1 == 0);
+	int isSingleRow = (fs->max_byte1 == 0);
 	int first = 1;
 	XCharStruct *defaultSize;
 	XCharStruct *charSize;
@@ -652,14 +653,14 @@ void XSharpTextExtentsStruct(Display *dpy, void *fontSet, ILString *str,
 	int temp;
 
 	/* Get the metrics for the default character */
-    if(isSingleRow)
+	if(isSingleRow)
 	{
 		CI_GET_DEFAULT_INFO_1D(fs, defaultSize);
-    }
+	}
 	else
 	{
 		CI_GET_DEFAULT_INFO_2D(fs, defaultSize);
-    }
+	}
 
 	/* Iterate over the characters and measure them */
 	overall.width = 0;
@@ -735,10 +736,9 @@ void XSharpTextExtentsXft(Display *dpy, void *fontSet, const char *str,
 {
 #ifdef USE_XFT_EXTENSION
 
-	/* TODO: 16-bit fonts */
-
 	XGlyphInfo extents;
-	XftTextExtents8(dpy, fontSet, (XftChar8 *)str, strlen(str), &extents);
+	
+	XftTextExtentsUtf8(dpy, fontSet, (XftChar8 *)str, strlen(str), &extents);
 
 	overall_ink_return->x = -(extents.x);
 	overall_ink_return->y = -(extents.y);
