@@ -125,7 +125,7 @@ public abstract class Array : ICloneable, ICollection, IEnumerable, IList
 		{
 			throw new ArgumentNullException("array");
 		}
-		else if(array.Rank != 1)
+		else if(array.GetRank() != 1)
 		{
 			throw new RankException(_("Arg_RankMustBe1"));
 		}
@@ -142,7 +142,7 @@ public abstract class Array : ICloneable, ICollection, IEnumerable, IList
 		{
 			throw new ArgumentNullException("array");
 		}
-		else if(array.Rank != 1)
+		else if(array.GetRank() != 1)
 		{
 			throw new RankException(_("Arg_RankMustBe1"));
 		}
@@ -252,21 +252,20 @@ public abstract class Array : ICloneable, ICollection, IEnumerable, IList
 		{
 			throw new ArgumentNullException("destinationArray");
 		}
-		if(sourceArray.Rank != destinationArray.Rank)
+		if(sourceArray.GetRank() != destinationArray.GetRank())
 		{
 			throw new RankException(_("Arg_MustBeSameRank"));
 		}
 		int srcLower = sourceArray.GetLowerBound(0);
-		int srcLength = sourceArray.Length;
+		int srcLength = sourceArray.GetLength();
 		int dstLower = destinationArray.GetLowerBound(0);
-		int dstLength = destinationArray.Length;
-		if(sourceIndex < srcLower || (sourceIndex - srcLower) > srcLength)
+		int dstLength = destinationArray.GetLength();
+		if(sourceIndex < srcLower)
 		{
 			throw new ArgumentOutOfRangeException
 				("sourceIndex", _("ArgRange_Array"));
 		}
-		if(destinationIndex < dstLower ||
-		   (destinationIndex - dstLower) > dstLength)
+		if(destinationIndex < dstLower)
 		{
 			throw new ArgumentOutOfRangeException
 				("destinationIndex", _("ArgRange_Array"));
@@ -276,8 +275,10 @@ public abstract class Array : ICloneable, ICollection, IEnumerable, IList
 			throw new ArgumentOutOfRangeException
 				("length", _("ArgRange_NonNegative"));
 		}
-		if((srcLength - (sourceIndex - srcLower)) < length ||
-		   (dstLength - (destinationIndex - dstLower)) < length)
+		int srcRelative = sourceIndex - srcLower;
+		int dstRelative = destinationIndex - dstLower;
+		if((srcLength - (srcRelative)) < length ||
+		   (dstLength - (dstRelative)) < length)
 		{
 			throw new ArgumentException(_("Arg_InvalidArrayRange"));
 		}
@@ -290,8 +291,8 @@ public abstract class Array : ICloneable, ICollection, IEnumerable, IList
 		if(arrayType1 == arrayType2)
 		{
 			InternalCopy
-				(sourceArray, sourceIndex - srcLower,
-				 destinationArray, destinationIndex - dstLower,
+				(sourceArray, srcRelative,
+				 destinationArray, dstRelative,
 				 length);
 			return;
 		}
@@ -310,10 +311,18 @@ public abstract class Array : ICloneable, ICollection, IEnumerable, IList
 		int index;
 		for(index = 0; index < length; ++index)
 		{
-			destinationArray.SetRelative(
-				Convert.ConvertObject(
-					sourceArray.GetRelative(sourceIndex + index - srcLower), 
-					arrayType2), destinationIndex + index - dstLower);
+			try
+			{
+				destinationArray.SetRelative(
+					Convert.ConvertObject(
+						sourceArray.GetRelative(srcRelative + index), 
+						arrayType2), dstRelative + index);
+			}
+			catch(FormatException e)
+			{
+				throw new InvalidCastException(String.Format(_("InvalidCast_FromTo"),
+ 						     arrayType1, arrayType2), e);
+			}
 		}
 	}
 
@@ -324,21 +333,25 @@ public abstract class Array : ICloneable, ICollection, IEnumerable, IList
 		{
 			throw new ArgumentNullException("array");
 		}
-		else if(array.Rank != 1 || Rank != 1)
+		else if(GetRank() != 1)
 		{
 			throw new RankException(_("Arg_RankMustBe1"));
 		}
+		else if(array.GetRank() > 1)
+		{
+			throw new ArgumentException("array", _("Arg_RankMustBe1"));
+		}
 		else
 		{
 			Copy(this, GetLowerBound(0), array,
-			     index + array.GetLowerBound(0), Length);
+			     index + array.GetLowerBound(0), GetLength());
 		}
 	}
 	int ICollection.Count
 	{
 		get
 		{
-			return Length;
+			return GetLength();
 		}
 	}
 	public virtual bool IsSynchronized
@@ -432,11 +445,11 @@ public abstract class Array : ICloneable, ICollection, IEnumerable, IList
 		{
 			throw new ArgumentNullException("lengths");
 		}
-		if(lengths.Length < 1)
+		if(lengths.GetLength() < 1)
 		{
 			throw new ArgumentException(_("Arg_MustHaveOneElement"));
 		}
-		for(index = lengths.Length - 1; index >= 0; --index)
+		for(index = lengths.GetLength() - 1; index >= 0; --index)
 		{
 			if(lengths[index] < 0)
 			{
@@ -464,15 +477,15 @@ public abstract class Array : ICloneable, ICollection, IEnumerable, IList
 		{
 			throw new ArgumentNullException("lowerBounds");
 		}
-		if(lengths.Length != lowerBounds.Length)
+		if(lengths.GetLength() != lowerBounds.GetLength())
 		{
 			throw new ArgumentException(_("Arg_MustBeSameSize"));
 		}
-		if(lengths.Length < 1)
+		if(lengths.GetLength() < 1)
 		{
 			throw new ArgumentException(_("Arg_MustHaveOneElement"));
 		}
-		for(index = lengths.Length - 1; index >= 0; --index)
+		for(index = lengths.GetLength() - 1; index >= 0; --index)
 		{
 			if(lengths[index] < 0)
 			{
@@ -487,7 +500,7 @@ public abstract class Array : ICloneable, ICollection, IEnumerable, IList
 	// Implement the IEnumerable interface.
 	public virtual IEnumerator GetEnumerator()
 	{
-		int rank = Rank;
+		int rank = GetRank();
 		if(rank == 1)
 		{
 			return new ArrayEnumerator1(this);
@@ -766,7 +779,7 @@ public abstract class Array : ICloneable, ICollection, IEnumerable, IList
 		{
 			throw new ArgumentNullException("indices");
 		}
-		if(indices.Length != Rank)
+		if(indices.GetLength() != GetRank())
 		{
 			throw new ArgumentException(_("Arg_MustBeSameSize"));
 		}
@@ -776,7 +789,7 @@ public abstract class Array : ICloneable, ICollection, IEnumerable, IList
 	// Get the value at a particular index within a single-dimensional array.
 	public Object GetValue(int index)
 	{
-		if(Rank != 1)
+		if(GetRank() != 1)
 		{
 			throw new ArgumentException(_("Arg_RankMustBe1"));
 		}
@@ -786,7 +799,7 @@ public abstract class Array : ICloneable, ICollection, IEnumerable, IList
 	// Get the value at a particular index within a double-dimensional array.
 	public Object GetValue(int index1, int index2)
 	{
-		if(Rank != 2)
+		if(GetRank() != 2)
 		{
 			throw new ArgumentException(_("Arg_RankMustBe2"));
 		}
@@ -796,7 +809,7 @@ public abstract class Array : ICloneable, ICollection, IEnumerable, IList
 	// Get the value at a particular index within a triple-dimensional array.
 	public Object GetValue(int index1, int index2, int index3)
 	{
-		if(Rank != 3)
+		if(GetRank() != 3)
 		{
 			throw new ArgumentException(_("Arg_RankMustBe3"));
 		}
@@ -861,7 +874,7 @@ public abstract class Array : ICloneable, ICollection, IEnumerable, IList
 		{
 			throw new ArgumentNullException("array");
 		}
-		if(array.Rank != 1)
+		if(array.GetRank() != 1)
 		{
 			throw new RankException(_("Arg_RankMustBe1"));
 		}
@@ -876,7 +889,7 @@ public abstract class Array : ICloneable, ICollection, IEnumerable, IList
 		{
 			throw new ArgumentNullException("array");
 		}
-		if(array.Rank != 1)
+		if(array.GetRank() != 1)
 		{
 			throw new RankException(_("Arg_RankMustBe1"));
 		}
@@ -892,7 +905,7 @@ public abstract class Array : ICloneable, ICollection, IEnumerable, IList
 		{
 			throw new ArgumentNullException("array");
 		}
-		if(array.Rank != 1)
+		if(array.GetRank() != 1)
 		{
 			throw new RankException(_("Arg_RankMustBe1"));
 		}
@@ -914,7 +927,7 @@ public abstract class Array : ICloneable, ICollection, IEnumerable, IList
 		{
 			throw new ArgumentNullException("array");
 		}
-		if(array.Rank != 1)
+		if(array.GetRank() != 1)
 		{
 			throw new RankException(_("Arg_RankMustBe1"));
 		}
@@ -937,7 +950,7 @@ public abstract class Array : ICloneable, ICollection, IEnumerable, IList
 		{
 			throw new ArgumentNullException("array");
 		}
-		if(array.Rank != 1)
+		if(array.GetRank() != 1)
 		{
 			throw new RankException(_("Arg_RankMustBe1"));
 		}
@@ -960,7 +973,7 @@ public abstract class Array : ICloneable, ICollection, IEnumerable, IList
 		{
 			throw new ArgumentNullException("array");
 		}
-		if(array.Rank != 1)
+		if(array.GetRank() != 1)
 		{
 			throw new RankException(_("Arg_RankMustBe1"));
 		}
@@ -995,7 +1008,7 @@ public abstract class Array : ICloneable, ICollection, IEnumerable, IList
 		{
 			throw new ArgumentNullException("array");
 		}
-		if(array.Rank != 1)
+		if(array.GetRank() != 1)
 		{
 			throw new RankException(_("Arg_RankMustBe1"));
 		}
@@ -1009,7 +1022,7 @@ public abstract class Array : ICloneable, ICollection, IEnumerable, IList
 		{
 			throw new ArgumentNullException("array");
 		}
-		if(array.Rank != 1)
+		if(array.GetRank() != 1)
 		{
 			throw new RankException(_("Arg_RankMustBe1"));
 		}
@@ -1048,7 +1061,7 @@ public abstract class Array : ICloneable, ICollection, IEnumerable, IList
 		{
 			throw new ArgumentNullException("indices");
 		}
-		if(indices.Length != Rank)
+		if(indices.GetLength() != GetRank())
 		{
 			throw new ArgumentException(_("Arg_MustBeSameSize"));
 		}
@@ -1058,7 +1071,7 @@ public abstract class Array : ICloneable, ICollection, IEnumerable, IList
 	// Set the value at a particular index within a single-dimensional array.
 	public void SetValue(Object value, int index)
 	{
-		if(Rank != 1)
+		if(GetRank() != 1)
 		{
 			throw new ArgumentException(_("Arg_RankMustBe1"));
 		}
@@ -1068,7 +1081,7 @@ public abstract class Array : ICloneable, ICollection, IEnumerable, IList
 	// Set the value at a particular index within a double-dimensional array.
 	public void SetValue(Object value, int index1, int index2)
 	{
-		if(Rank != 2)
+		if(GetRank() != 2)
 		{
 			throw new ArgumentException(_("Arg_RankMustBe2"));
 		}
@@ -1078,7 +1091,7 @@ public abstract class Array : ICloneable, ICollection, IEnumerable, IList
 	// Set the value at a particular index within a triple-dimensional array.
 	public void SetValue(Object value, int index1, int index2, int index3)
 	{
-		if(Rank != 3)
+		if(GetRank() != 3)
 		{
 			throw new ArgumentException(_("Arg_RankMustBe3"));
 		}
@@ -1180,7 +1193,7 @@ public abstract class Array : ICloneable, ICollection, IEnumerable, IList
 		{
 			throw new ArgumentNullException("array");
 		}
-		if(array.Rank != 1)
+		if(array.GetRank() != 1)
 		{
 			throw new RankException(_("Arg_RankMustBe1"));
 		}
@@ -1205,13 +1218,13 @@ public abstract class Array : ICloneable, ICollection, IEnumerable, IList
 		{
 			throw new ArgumentNullException("keys");
 		}
-		if(keys.Rank != 1)
+		if(keys.GetRank() != 1)
 		{
 			throw new RankException(_("Arg_RankMustBe1"));
 		}
 		if(items != null)
 		{
-			if(items.Rank != 1)
+			if(items.GetRank() != 1)
 			{
 				throw new RankException(_("Arg_RankMustBe1"));
 			}
@@ -1219,7 +1232,7 @@ public abstract class Array : ICloneable, ICollection, IEnumerable, IList
 			{
 				throw new ArgumentException(_("Arg_LowBoundsMustMatch"));
 			}
-			if(items.Length < keys.Length)
+			if(items.GetLength() < keys.GetLength())
 			{
 				throw new ArgumentException(_("Arg_ShortItemsArray"));
 			}
@@ -1246,7 +1259,7 @@ public abstract class Array : ICloneable, ICollection, IEnumerable, IList
 		{
 			throw new ArgumentNullException("array");
 		}
-		if(array.Rank != 1)
+		if(array.GetRank() != 1)
 		{
 			throw new RankException(_("Arg_RankMustBe1"));
 		}
@@ -1287,7 +1300,7 @@ public abstract class Array : ICloneable, ICollection, IEnumerable, IList
 		{
 			throw new ArgumentNullException("keys");
 		}
-		if(keys.Rank != 1)
+		if(keys.GetRank() != 1)
 		{
 			throw new RankException(_("Arg_RankMustBe1"));
 		}
@@ -1308,7 +1321,7 @@ public abstract class Array : ICloneable, ICollection, IEnumerable, IList
 		}
 		if(items != null)
 		{
-			if(items.Rank != 1)
+			if(items.GetRank() != 1)
 			{
 				throw new RankException(_("Arg_RankMustBe1"));
 			}
@@ -1337,7 +1350,7 @@ public abstract class Array : ICloneable, ICollection, IEnumerable, IList
 	}
 	void IList.Clear()
 	{
-		Clear(this, 0, Length);
+		Clear(this, 0, GetLength());
 	}
 	bool IList.Contains(Object value)
 	{
@@ -1492,9 +1505,9 @@ public abstract class Array : ICloneable, ICollection, IEnumerable, IList
 		{
 			throw new ArgumentNullException("lengths");
 		}
-		int[] ilengths = new int [lengths.Length];
+		int[] ilengths = new int [lengths.GetLength()];
 		int posn;
-		for(posn = 0; posn < lengths.Length; ++posn)
+		for(posn = 0; posn < lengths.GetLength(); ++posn)
 		{
 			ilengths[posn] = DowngradeLength("lengths", lengths[posn]);
 		}
@@ -1530,9 +1543,9 @@ public abstract class Array : ICloneable, ICollection, IEnumerable, IList
 		{
 			throw new ArgumentNullException("indices");
 		}
-		int[] iindices = new int [indices.Length];
+		int[] iindices = new int [indices.GetLength()];
 		int posn;
-		for(posn = 0; posn < indices.Length; ++posn)
+		for(posn = 0; posn < indices.GetLength(); ++posn)
 		{
 			iindices[posn] = DowngradeIndex2("indices", indices[posn]);
 		}
@@ -1565,9 +1578,9 @@ public abstract class Array : ICloneable, ICollection, IEnumerable, IList
 		{
 			throw new ArgumentNullException("indices");
 		}
-		int[] iindices = new int [indices.Length];
+		int[] iindices = new int [indices.GetLength()];
 		int posn;
-		for(posn = 0; posn < indices.Length; ++posn)
+		for(posn = 0; posn < indices.GetLength(); ++posn)
 		{
 			iindices[posn] = DowngradeIndex2("indices", indices[posn]);
 		}
