@@ -25,10 +25,11 @@ namespace System
 #if CONFIG_EXTENDED_CONSOLE
 
 [Flags]
+[Obsolete("Use ConsoleSpecialKey instead")]
 public enum ConsoleSpecialKeys
 {
-	ControlC			= 0x0001,		// guess - confirm later
-	ControlBreak		= 0x0002		// guess - confirm later
+	ControlC			= 0,
+	ControlBreak		= 1
 
 }; // enum ConsoleSpecialKeys
 
